@@ -1,17 +1,13 @@
 package Alien::TinyCC;
 
-use strict;
-use warnings;
-
 # Follow Golden's Version Rule: http://www.dagolden.com/index.php/369/version-numbers-should-be-boring/
-our $VERSION = "0.06_01";
+our $VERSION = "0.01";
 $VERSION = eval $VERSION;
 
 use File::ShareDir;
 use File::Spec;
 use Env qw( @PATH );
 use Carp;
-use Config;
 
 ###################################
 # Find the Distribution Directory #
@@ -23,7 +19,7 @@ use Config;
 my $dist_dir;
 
 my $mod_path = $INC{'Alien/TinyCC.pm'};
-if ($mod_path =~ s/(.*)blib.*/$1share/) {
+if ($mod_path =~ s/(.*)blib.*/${1}share/) {
 	$dist_dir = $mod_path;
 	croak('Looks like Alien::TinyCC is being invoked from blib, but I cannot find build-time sharedir!')
 		unless -d $dist_dir;
@@ -75,20 +71,6 @@ sub MB_linker_flags {
 	return ('-L' . libtcc_library_path, '-ltcc');
 }
 
-#################################
-# ExtUtils::MakeMaker Functions #
-#################################
-
-sub EUMM_LIBS {
-	return (LIBS => ['-L' . libtcc_library_path . '\libtcc -ltcc']) if $^O =~ /MSWin/;
-	return;
-}
-
-sub EUMM_OBJECT {
-	return OBJECT => '$(O_FILES)' if $^O =~ /MSWin/;
-	return OBJECT => '$(O_FILES) ' . File::Spec->catdir(libtcc_library_path, 'libtcc'.$Config{lib_ext}),
-}
-
 # version
 
 1;
@@ -255,6 +237,7 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Alien::TinyCC
 
+
 You can also look for information at:
 
 =over 4
@@ -276,10 +259,6 @@ L<http://cpanratings.perl.org/d/Alien-TinyCC>
 L<http://p3rl.org/Alien::TinyCC>
 L<http://search.cpan.org/dist/Alien-TinyCC/>
 
-=item * Stack Overflow
-
-L<//http://stackoverflow.com/questions/tagged/tcc>
-
 =back
 
 =head1 ACKNOWLEDGEMENTS
@@ -289,7 +268,7 @@ had the Windows install command nicely packaged up! How amazing!
 
 =head1 LICENSE AND COPYRIGHT
 
-Code copyright 2013 Dickinson College. Documentation copyright 2013 David
+Code copyright 201 Dickinson College. Documentation copyright 2013 David
 Mertens.
 
 Everything not contained in the F<src/> directory is free software, the
